dlrnapi-client
==============

This is a Python client and command-line interface for the `DLRN`_ API.

It has been automatically generated by the `Swagger Codegen`_ project:

-  API version: 1.0.0
-  Package version: 1.0.0
-  Build package: io.swagger.codegen.languages.PythonClientCodegen

Requirements.
-------------

Python 2.7 or 3.6+

Installation & Usage
--------------------

You can install directly from Github

.. code:: sh

   pip install git+https://github.com/softwarefactory-project/dlrnapi_client.git

(you may need to run ``pip`` with root permission:
``sudo pip install git+https://github.com/softwarefactory-project/dlrnapi_client.git``)

Then import the package:

.. code:: python

   import dlrnapi_client

Or you can run the client directly:

.. code:: bash

   $ dlrnapi -h

Setuptools
~~~~~~~~~~

Install via `Setuptools`_.

.. code:: sh

   python setup.py install --user

(or ``sudo python setup.py install`` to install the package for all
users)

Then import the package:

.. code:: python

   import dlrnapi_client

Or you can run the client directly:

.. code:: bash

   $ dlrnapi -h

Getting Started
---------------

Please follow the `installation procedure`_ and then run the following:

.. code:: python

   from __future__ import print_function
   import time
   import dlrnapi_client
   from dlrnapi_client.rest import ApiException
   from pprint import pprint
   # create an instance of the API class
   api_instance = dlrnapi_client.DefaultApi()
   params = dlrnapi_client.Params() # Params | The JSON params to post

   try:
       api_response = api_instance.api_last_tested_repo_get(params)
       pprint(api_response)
   except ApiException as e:
       print("Exception when calling DefaultApi->api_last_tested_repo_get: %s\n" % e)

Documentation for command-line
------------------------------

-  `dlrnapi`_

Documentation for API Endpoints
-------------------------------

All URIs are relative to http://127.0.0.1:5000

============ ============================ ============================== ===========
Class        Method                       HTTP request                   Description
============ ============================ ============================== ===========
*DefaultApi* `api_last_tested_repo_get`_  **GET** /api/last_tested_repo
*DefaultApi* `api_last_tested_repo_post`_ **POST** /api/last_tested_repo
*DefaultApi* `api_promote_post`_          **POST** /api/promote
*DefaultApi* `api_promote_batch_post`_    **POST** /api/promote-batch
*DefaultApi* `api_promotions_get`_        **POST** /api/promotions
*DefaultApi* `api_build_metrics_get`_     **GET** /api/metrics/builds
*DefaultApi* `api_remote_import_post`_    **POST** /api/remote/import
*DefaultApi* `api_repo_status_get`_       **GET** /api/repo_status
*DefaultApi* `api_report_result_post`_    **POST**/api/report_result
*DefaultApi* `api_agg_status_get`_        **GET**/api/agg_status
============ ============================ ============================== ===========

Documentation For Models
------------------------

-  `CIVote`_
-  `Import`_
-  `Params`_
-  `Params1`_
-  `Params2`_
-  `Params3`_
-  `Promotion`_
-  `Repo`_

Documentation For Authorization
-------------------------------

basicAuth
---------

-  **Type**: HTTP basic authentication

Environment variables
---------------------

-  *DLRNAPI_PASSWORD*: set the password to authenticate against the DLRN
   API.
-  *SSL_VERIFY*: set to ‘0’ to deactivate SSL verification when talking
   to the DLRN API.

Author
------

Javier Peña (jpena@redhat.com)

.. _DLRN: https://github.com/softwarefactory-project/DLRN
.. _Swagger Codegen: https://github.com/swagger-api/swagger-codegen
.. _Setuptools: http://pypi.python.org/pypi/setuptools
.. _installation procedure: #installation--usage
.. _dlrnapi: docs/command-line.md
.. _api_last_tested_repo_get: docs/DefaultApi.md#api_last_tested_repo_get
.. _api_last_tested_repo_post: docs/DefaultApi.md#api_last_tested_repo_post
.. _api_promote_post: docs/DefaultApi.md#api_promote_post
.. _api_promote_batch_post: docs/DefaultApi.md#api_promote_batch_post
.. _api_promotions_get: docs/DefaultApi.md#api_promotions_get
.. _api_build_metrics_get: docs/DefaultApi.md#api_build_metrics_get
.. _api_remote_import_post: docs/DefaultApi.md#api_remote_import_post
.. _api_repo_status_get: docs/DefaultApi.md#api_repo_status_get
.. _api_report_result_post: docs/DefaultApi.md#api_report_result_post
.. _api_agg_status_get: docs/DefaultApi.md#api_agg_status_get
.. _CIVote: docs/CIVote.md
.. _Import: docs/ModelImport.md
.. _Params: docs/Params.md
.. _Params1: docs/Params1.md
.. _Params2: docs/Params2.md
.. _Params3: docs/Params3.md
.. _Promotion: docs/Promotion.md
.. _Repo: docs/Repo.md
